<?php defined('ABSPATH') OR exit('No direct script access allowed');

class WPLS_Sample_Plugin {

	var $shop_url;
	var $product_code;
	var $is_envato = false;
	var $ouput_format = 'json';
	
	public function __construct( $shop_url, $product_code ){
		
		$this->shop_url = $shop_url;
		$this->product_code = $product_code;
		
		add_action( 'admin_menu', array($this, 'license_menu') );
		add_action( 'admin_footer', array($this, 'wpls_verify_js'), 999);
		add_action( 'wp_ajax_' . $this->product_code . '_license_activate', array($this, 'license_activate') );
		add_action( 'wp_ajax_' . $this->product_code . '_license_deactivate', array($this, 'license_deactivate') );
		add_action( $this->product_code . '_cron_hook', array($this, 'check_serial_valid') );
		add_filter( 'cron_schedules', array($this, 'cron_schedule') );
			
		if (!wp_next_scheduled( $this->product_code . '_cron_hook' ) ) {
			wp_schedule_event( time(), $this->product_code . '_cron_events', $this->product_code . '_cron_hook' );
		}
		
	}
	
	public function is_envato( $status = false ){
		$this->is_envato = $status;
	}

	public function set_output( $output = 'json' ){
		$this->ouput_format = $output;
	}

	public function license_menu() {
		add_plugins_page( 'Licensed Plugin', 'Licensed Plugin', 'manage_options', 'licensed-plugin', array($this, 'license_page') );
	}
	
	public function license_page() {
		$license = get_option( $this->product_code . '_license_key', '' );
		$email 	= get_option( $this->product_code . '_license_email', '' );
		$status = get_option( $this->product_code . '_license_status' );
	?>
	
	<div class="wrap nosubsub">
		<h2>Sample Licensed Plugin</h2>
		<form method="post" id="<?=$this->product_code;?>-verify">
			<input type="hidden" id="<?=$this->product_code;?>-action" name="<?=$this->product_code;?>-action" value="<?=$this->serial_valid() ? $this->product_code . '_license_deactivate' : $this->product_code . '_license_activate';?>" />
			<table class="wp-list-table widefat tags ui-sortable">
				<tbody>
					<tr>
						<td valign="top"><label for="<?=$this->product_code;?>-license">License Key:</label></td>
						<td>
							<input class="textfield" name="<?=$this->product_code;?>-license" size="50" type="text" id="<?=$this->product_code;?>-license" value="<?php echo $license; ?>" required />
							<p class="description"><?php _e('Valid License  to make All feature work correctly', 'wpls') ?></p>
						</td>
					</tr>
					<tr>
						<td valign="top"><label for="<?=$this->product_code;?>-email">Email:</label></td>
						<td>
							<input class="textfield" name="<?=$this->product_code;?>-email" size="50" type="text" id="<?=$this->product_code;?>-email" value="<?php echo $email; ?>" required />
							<p class="description"><?php _e('Please provide your registered email with us', 'wpls') ?></p>
						</td>
					</tr>
					<tr>
						<td></td>
						<td>
							<input type="submit" class="button-primary" id="<?=$this->product_code;?>-saveS" name="saveS" value="<?=$this->serial_valid() ? __('Deactivate') : __('Activate');?>">
							<p class="<?=$this->product_code;?>-pesan"></p>
						</td>
					</tr>
					<tr id="<?=$this->product_code;?>-status" style="<?=$this->serial_valid() ? '' : 'display:none;';?>">
						<td colspan="2" id="td-status">
							<?php echo '<pre>', print_r($this->authorize_action($license, $email), 1), '</pre>';?>
						</td>
					</tr>
				</tbody>
			</table>
		</form>
	</div>
	<?php
	}
	
	public function check_serial_valid($action = 'validate') {
		$license = get_option( $this->product_code . '_license_key', '' );
		$email 	= get_option( $this->product_code . '_license_email', '' );
		$authorize = $this->authorize_action($serial, $email, $action);
		if($authorize->valid){
			return true;
		}
		return false;
	}
	
	private function authorize_action( $purchase_code = '', $email = '', $action = 'validate' ) {
		global $wp_version;
		
		$domain = home_url();
		$api_params = array(
			'wpls-verify' => $purchase_code,
			'action' => $action, 
			'domain' => $domain,
			'product' => $this->product_code,
			'validip' => isset($_SERVER['SERVER_ADDR']) ? $_SERVER['SERVER_ADDR'] : $_SERVER['LOCAL_ADDR'],
			'envato_item' => $this->is_envato ? 'yes' : 'no', // uncomment this if you use envato receipt as license key
			'type' => $this->ouput_format, // default format is json, you may change 'json' or 'xml'
		);
		
		$request = add_query_arg( $api_params, $this->shop_url );
		$response = wp_remote_get( $request, array( 'timeout' => 15, 'sslverify' => false ) );
		
		if ( is_wp_error( $response ) )
			return false;
				
		$authorize_data = json_decode( wp_remote_retrieve_body( $response ) );	
		if(empty($authorize_data) || $authorize_data === NULL || $authorize_data === false) return false;				
		update_option($this->product_code . '_license_status', $authorize_data->valid);
		return $authorize_data;
	}
	
	public function serial_valid() {
		return get_option($this->product_code . '_license_status', false);
	}
	
	public function wpls_verify_js(){
	?>
	<script>
		jQuery('#<?=$this->product_code;?>-verify').on('submit', function(e){
			e.preventDefault();
			var action = jQuery('#<?=$this->product_code;?>-action').val(),
				email = jQuery('#<?=$this->product_code;?>-email').val(),
				code = jQuery('#<?=$this->product_code;?>-license').val();
				
			jQuery.ajax({
				type: "POST",
				url : '<?=admin_url('admin-ajax.php');?>',
				data: {'action' : action, 'email' : email, 'code': code},
				beforeSend: function(){
					jQuery('#<?=$this->product_code;?>-saveS').prop('disabled', true).val('Please wait..');
				},
				success : function(data){
					var btn_value = 'Activate';
					if( data ){
						if(data.valid){
							if(action == '<?=$this->product_code;?>_license_activate'){
								var btn_value = 'Deactivate';
								jQuery('#<?=$this->product_code;?>-action').val('<?=$this->product_code;?>_license_deactivate');
								jQuery('.<?=$this->product_code;?>-pesan').html('<span style="color:green;">Congratulation, your license already activated</span>');
								jQuery('tr#<?=$this->product_code;?>-status').load(window.location.href + ' #td-status').show();
							}
							else{
								jQuery('#<?=$this->product_code;?>-action').val('<?=$this->product_code;?>_license_activate');
								jQuery('#<?=$this->product_code;?>-license').val('');
								jQuery('#<?=$this->product_code;?>-email').val('');
								jQuery('.<?=$this->product_code;?>-pesan').html('<span style="color:green;">Congratulation, your license successful deactivated</span>');
								jQuery('tr#<?=$this->product_code;?>-status').load(window.location.href + ' #td-status').hide();
							}
							
							location.reload();
						}
						else {
							jQuery('.<?=$this->product_code;?>-pesan').html('<span style="color:red;">'+data.info.message+'</span>');
						}
					}
	
					jQuery('#<?=$this->product_code;?>-saveS').prop('disabled', false).val(btn_value);
				},
				error: function(data){
					console.log(data);
					jQuery('#<?=$this->product_code;?>-saveS').prop('disabled', false).val('Update');
				}
			});
		});
	</script>
	
	<?php
	
	}
	
	public function license_activate(){
		if(isset($_POST['email']) && isset($_POST['code'])){
			$return = $this->authorize_action( $_POST['code'], $_POST['email'], 'activate' );
			if($return->valid){
				update_option( $this->product_code . '_license_key', $_POST['code']);
				update_option( $this->product_code . '_license_email', $_POST['email']);
			}
			header('Content-type: application/json');
			echo json_encode($return, JSON_PRETTY_PRINT);
			die();
		}
	}
	
	public function license_deactivate(){
		if(isset($_POST['email']) && isset($_POST['code'])){
			$return = $this->authorize_action( $_POST['code'], $_POST['email'], 'deactivate' );
			if($return->valid){
				update_option( $this->product_code . '_license_key', '');
				update_option( $this->product_code . '_license_email', '');
				update_option( $this->product_code . '_license_status', false);
			}
			header('Content-type: application/json');
			echo json_encode($return, JSON_PRETTY_PRINT);
			die();
		}
	}
	
	public function cron_schedule( $schedules ) {
		$schedules[ $this->product_code . '_cron_events' ] = array(
			'interval' => 43200, // Every 12 hours
			'display'  => __( 'Twice a day' ),
		);
		return $schedules;
	}
}