<?php
/**
 * This is just a demonstration of how theme licensing works with
 * Wordpress Licensing System.
 *
 * @package WordPress
 * @subpackage WPLS Sample Theme
 */

// This is the URL our updater / license checker pings. This should be the URL of the site with WPLS installed
if(!defined('WPLS_SAMPLE_STORE_URL'))
define( 'WPLS_SAMPLE_STORE_URL', 'https://basic.wpdev.club' ); // add your own unique prefix to prevent conflicts

// The name of your product. This should match the download name in WPLS exactly
define( 'WPLS_SAMPLE_THEME_CODE', 'sampleTheme' ); // add your own unique your-wpls-theme-product-code to prevent conflicts
define( 'WPLS_SAMPLE_THEME_SLUG', 'wpls-sample-theme' ); // add your own unique your-wpls-theme-product-slug to prevent conflicts

require_once('theme-updates.php');
new WPLSThemeUpdater_sampleTheme( WPLS_SAMPLE_STORE_URL, basename( get_template_directory() ), WPLS_SAMPLE_THEME_CODE, get_option( 'wpls_sample_theme_license_key', '' ));

/***********************************************
* Add our menu item
***********************************************/

function wpls_sample_theme_license_menu() {
	add_theme_page( 'Licensed Theme', 'Licensed Theme', 'manage_options', 'licensed-theme', 'wpls_sample_theme_license_page' );
}
add_action('admin_menu', 'wpls_sample_theme_license_menu');

/***********************************************
* Sample settings page, substitute with yours
***********************************************/

function wpls_sample_theme_license_page() {
	$license = get_option( 'wpls_sample_theme_license_key' );
	$email 	= get_option( 'wpls_sample_theme_license_email', '' );
	$status = get_option( 'wpls_sample_theme_license_key_status' );

?>

<div class="wrap nosubsub">
	<h2><?php _e('Licensed Theme Options'); ?></h2>
	<form method="post" id="sample-theme-verify">
		<input type="hidden" id="sample-theme-action" name="sample-theme-action" value="<?=sample_theme_serial_valid() ? 'sample_theme_license_deactivate':'sample_theme_license_activate';?>" />
		<table class="wp-list-table widefat tags ui-sortable">
           	<tbody>
                <tr>
                   	<td valign="top"><label for="sample-theme-license">License Key:</label></td>
                    <td>
                       	<input class="textfield" name="sample-theme-license" size="50" type="text" id="sample-theme-license" value="<?php echo $license; ?>" required />
                        <p class="description"><?php _e('Valid License  to make All feature work correctly', 'wpls') ?></p>
                    </td>
                </tr>
                <tr>
                   	<td valign="top"><label for="sample-theme-license">Email:</label></td>
                    <td>
                       	<input class="textfield" name="sample-theme-email" size="50" type="text" id="sample-theme-email" value="<?php echo $email; ?>" required />
                        <p class="description"><?php _e('Please provide your registered email with us', 'wpls') ?></p>
                    </td>
				</tr>
				<tr>
                	<td></td>
                    <td>
                    	<input type="submit" class="button-primary" id="saveS" name="saveS" value="<?=sample_theme_serial_valid() ? __('Deactivate') : __('Activate');?>">
                        <p class="pesan"></p>
                    </td>
				</tr>
                <tr id="sample-status" style="<?=sample_theme_serial_valid() ? '' : 'display:none;';?>">
                	<td colspan="2" id="td-status">
                    	<?php echo '<pre>', print_r(sample_theme_authorize_action($license, $email), 1), '</pre>';?>
                    </td>
                </tr>
			</tbody>
		</table>
	</form>
</div>

<?php
}

function sample_theme_check_serial_valid($action = 'validate') {
	$license = get_option( 'wpls_sample_theme_license_key', '' );
	$email 	= get_option( 'wpls_sample_theme_license_email', '' );
	$authorize = sample_theme_authorize_action($serial, $email, $action);
	if($authorize->valid){
		return true;
	}
	return false;
}

function sample_theme_authorize_action( $purchase_code = '', $email = '', $action = 'validate' ) {
	global $wp_version;
	
	$domain = home_url();
	$api_params = array(
		'wpls-verify' => $purchase_code,
		'action' => $action, 
		'domain' => $domain,
		'product' => WPLS_SAMPLE_THEME_CODE,
		'validip' => isset($_SERVER['SERVER_ADDR']) ? $_SERVER['SERVER_ADDR'] : $_SERVER['LOCAL_ADDR'],
		//'envato_item' => 'yes', // uncomment this if you use envato receipt as license key
		//'type' => 'json', // default format is json, you may change 'json' or 'xml'
	);
	
	$request = add_query_arg( $api_params, WPLS_SAMPLE_STORE_URL );
	$response = wp_remote_get( $request, array( 'timeout' => 15, 'sslverify' => false ) );
	
	if ( is_wp_error( $response ) )
		return false;
			
	$authorize_data = json_decode( wp_remote_retrieve_body( $response ) );	
	if(empty($authorize_data) || $authorize_data === NULL || $authorize_data === false) return false;				
	update_option('wpls_sample_theme_license_key_status', $authorize_data->valid);
	return $authorize_data;
}

function sample_theme_serial_valid() {
	return get_option('wpls_sample_theme_license_key_status', false);
}

function wpls_sample_theme_verify_js(){
?>
<script>
	jQuery('#sample-theme-verify').on('submit', function(e){
		e.preventDefault();
		var action = jQuery('#sample-theme-action').val(),
			email = jQuery('#sample-theme-email').val(),
			code = jQuery('#sample-theme-license').val();
			
		jQuery.ajax({
			type: "POST",
			url : '<?=admin_url('admin-ajax.php');?>',
			data: {'action' : action, 'email' : email, 'code': code},
			beforeSend: function(){
				jQuery('#saveS').prop('disabled', true).val('Please wait..');
			},
			success : function(data){
				var btn_value = 'Activate';
				if( data ){
					if(data.valid){
						if(action == 'sample_theme_license_activate'){
							var btn_value = 'Deactivate';
							jQuery('#sample-theme-action').val('sample_theme_license_deactivate');
							jQuery('.pesan').html('<span style="color:green;">Congratulation, your license already activated</span>');
							jQuery('tr#sample-status').load(window.location.href + ' #td-status').show();
						}
						else{
							jQuery('#sample-theme-action').val('sample_theme_license_activate');
							jQuery('#sample-theme-license').val('');
							jQuery('#sample-theme-email').val('');
							jQuery('.pesan').html('<span style="color:green;">Congratulation, your license successful deactivated</span>');
							jQuery('tr#sample-status').load(window.location.href + ' #td-status').hide();
						}
						
						location.reload();
					}
					else {
						jQuery('.pesan').html('<span style="color:red;">'+data.info.message+'</span>');
					}
				}
				
				jQuery('#saveS').prop('disabled', false).val(btn_value);
			}
		});
	});
</script>

<?php

}

add_action( 'admin_footer', 'wpls_sample_theme_verify_js', 999);
add_action( 'wp_ajax_sample_theme_license_activate', 'wpls_sample_theme_license_activate' );
add_action( 'wp_ajax_sample_theme_license_deactivate', 'wpls_sample_theme_license_deactivate' );

function wpls_sample_theme_license_activate(){
	if(isset($_POST['email']) && isset($_POST['code'])){
		$return = sample_theme_authorize_action( $_POST['code'], $_POST['email'], 'activate' );
		if($return->valid){
			update_option( 'wpls_sample_theme_license_key', $_POST['code']);
			update_option( 'wpls_sample_theme_license_email', $_POST['email']);
		}
		header('Content-type: application/json');
		echo json_encode($return, JSON_PRETTY_PRINT);
		die();
	}
}

function wpls_sample_theme_license_deactivate(){
	if(isset($_POST['email']) && isset($_POST['code'])){
		$return = sample_theme_authorize_action( $_POST['code'], $_POST['email'], 'deactivate' );
		if($return->valid){
			update_option( 'wpls_sample_theme_license_key', '');
			update_option( 'wpls_sample_theme_license_email', '');
			update_option( 'wpls_sample_theme_license_key_status', false);
		}
		header('Content-type: application/json');
		echo json_encode($return, JSON_PRETTY_PRINT);
		die();
	}
}

add_filter( 'cron_schedules', 'wpls_sample_theme_cron_schedule' );
add_action( 'wpls_sample_theme_cron_hook', 'sample_theme_check_serial_valid' );
	
if (!wp_next_scheduled( 'wpls_sample_theme_cron_hook' ) ) {
	wp_schedule_event( time(), 'wpls_sample_theme_cron_events', 'wpls_sample_theme_cron_hook' );
}

function wpls_sample_theme_cron_schedule( $schedules ) {
	$schedules['wpls_sample_theme_cron_events'] = array(
		'interval' => 43200, // Every 12 hours
		'display'  => __( 'Twice a day' ),
	);
	return $schedules;
}
