<?php defined('ABSPATH') OR exit('No direct script access allowed');

if( !class_exists('WPLSThemeUpdater_sampleTheme') ) {
	class WPLSThemeUpdater_sampleTheme {

		var $api_url;
		var $theme_id = 2259;
		var $theme_slug;
		var $license_key;
		var $product_code;
		
		public function __construct( $api_url, $theme_slug, $product_code = null, $license_key = null ) {
			$this->api_url = $api_url;
			$this->theme_slug = $theme_slug;
			$this->license_key = $license_key;
			$this->product_code = $product_code;
			
			add_filter( 'pre_set_site_transient_update_themes', array(&$this, 'check_for_update') );
			
			// This is for testing only!
			//set_site_transient('update_themes', null);
		
		}
		
		public function check_for_update( $transient ) {
			if (empty($transient->checked)) return $transient;
			
			$request_args = array(
				'id' => $this->theme_id,
				'slug' => $this->theme_slug,
				'version' => $transient->checked[$this->theme_slug],
				'product' => $this->product_code,
				'domain' => home_url()
			);
			
			if ($this->license_key) $request_args['license'] = $this->license_key;
			
			$request_string = $this->prepare_request( 'theme_update', $request_args );
			$raw_response = wp_remote_post( $this->api_url, $request_string );
			
			$response = null;
			if( !is_wp_error($raw_response) && ($raw_response['response']['code'] == 200) )
				$response = unserialize($raw_response['body']);
				
			if( !empty($response) ) // Feed the update data into WP updater
				$transient->response[$this->theme_slug] = $response;
			
			return $transient;
		
		}
		
		public function prepare_request( $action, $args ) {
			global $wp_version;
			
			return array(
				'body' => array(
					'wpls-action' => $action,
					'package' => 'theme',
					'request' => serialize($args),
					'api-key' => md5(home_url())
				),
				'user-agent' => 'WordPress/'. $wp_version .'; '. home_url()
			);
		
		}
		
		private function buat_log( $message, $success = true, $end = false ){
			if (!file_exists(WP_CONTENT_DIR . '/uploads/log.txt')) {
				file_put_contents(WP_CONTENT_DIR . '/uploads/log.txt', 'Shipping Logs'."\r\n");
			}
	
			$text = "[".date( "m/d/Y g:i A" )."] - ".( $success ? "SUCCESS :" : "FAILURE :" ).$message."\n";
	
			if ( $end ){
				$text .= "\n------------------------------------------------------------------\n\n";
			}
		
			$debug_log_file_name = WP_CONTENT_DIR . '/uploads/log.txt';
			$fp = fopen( $debug_log_file_name, "a" );
			fwrite( $fp, $text );
			fclose( $fp );
		}

	}
}